/*
 * Written by:
 *	Paul D. Boyle
 *	Department of Chemistry
 *	Box 8204
 *	North Carolina State University
 *	Raleigh, NC 27695-8204
 *
 *	February 1999
 *
 *  This source file is part of the twindex program and is under the GPL.
 *  Program: twindex -- a program for analysis of X-ray diffraction data
 *  from non-merohedrally twinned crystals.
 *  Author:  Paul D. Boyle
 *  Copyright (C) 2000  Paul D. Boyle
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#define _XOPEN_SOURCE
#include <stdlib.h>
#include "twindex.h"
#include "output.h"

/* the mode argument can either be OVERLAP or REINDEX (see twindex.h).
 * this is necessary because ReIndexCompositeData and CalculateOverlaps
 * do the calculation is slightly different ways.
 */

void OutputHKLF5File( FILE *hklf5, ShelxHKL *refl, int n_comp, int mode )
{

    int k_count,
        upper, 
        lower;

    switch( mode ) {
       case OVERLAP:
          upper = n_comp - 1;
          lower = -1;
          break;
       case REINDEX:
          upper = n_comp;
          lower = 0;
          break;
       default:
          fputs( "Output mode not properly specified. Exiting.\n",
                  stderr );
          exit( EXIT_SUCCESS );
          break;
    }
         
    for( k_count = upper; k_count > lower; k_count-- ) {
         if( 0 != refl[k_count].i_comp ) {
             if( refl[k_count].f_squared < 99999.99 )
                 fprintf( hklf5, HKLF5_FORMAT_1, refl[k_count].hkl[0],
                                                 refl[k_count].hkl[1],
                                                 refl[k_count].hkl[2],
                                                 refl[k_count].f_squared,
                                                 refl[k_count].sigma,
                                                 refl[k_count].i_comp);
             else 
                 fprintf( hklf5, HKLF5_FORMAT_2, refl[k_count].hkl[0],
                                                 refl[k_count].hkl[1],
                                                 refl[k_count].hkl[2],
                                                 refl[k_count].f_squared,
                                                 refl[k_count].sigma,
                                                 refl[k_count].i_comp );
         }
    }
    return;
}
